@@ -7,13 +7,10 @@ from sklearn.metrics import accuracy_score, roc_auc_score, classification_report
 from sklearn.model_selection import cross_val_score
 import xgboost as xgb
 from xgboost import XGBClassifier
+from sklearn.preprocessing import LabelBinarizer
 from sklearn.neighbors import KNeighborsClassifier
-from pneuro import appLogger
-from pneuro import file_methods
-#from appLogger import AppLogger
-
-
-#from file_methods import FileOperation
+from pneuro.appLogger import AppLogger
+from pneuro.file_methods import FileOperation
 
 class ClassificationModelTuner():
     """
@@ -26,9 +23,9 @@ class ClassificationModelTuner():
         """
 
     def __init__(self):
-        self.file_object = open('classificationModelsLogs.txt', 'a+')
-        self.logger_object = appLogger.AppLogger()
-        self.file_operation = file_methods.FileOperation()
+        self.file_object = open('pneuro/logs/classificationTrainingLogs.txt', 'a+')
+        self.logger_object = AppLogger()
+        self.file_operation = FileOperation()
 
     def get_tuned_random_forest_classifier(self, x_train, y_train):
         """
@@ -212,10 +209,16 @@ class ClassificationModelTuner():
                     test_y.unique()) == 1:  # if there is only one label in y, then roc_auc_score returns error. We will use accuracy in that case
                 self.xgboost_score = accuracy_score(test_y, self.prediction_xgboost)
                 self.logger_object.log(self.file_object, 'Accuracy for XGBoost:' + str(self.xgboost_score))  # Log AUC
-            else:
+            elif len(test_y.unique()) == 2:
                 self.xgboost_score = roc_auc_score(test_y, self.prediction_xgboost)  # AUC for XGBoost
                 self.logger_object.log(self.file_object, 'AUC for XGBoost:' + str(self.xgboost_score))  # Log AUC
-
+            else:
+                lb = LabelBinarizer()
+                lb.fit(test_y)
+                test_y_xg = lb.transform(test_y)
+                self.prediction_xgboost = lb.transform(self.prediction_xgboost)
+                self.xgboost_score = roc_auc_score(test_y_xg, self.prediction_xgboost)  # AUC for XGBoost
+                self.logger_object.log(self.file_object, 'AUC for XGBoost:' + str(self.xgboost_score))  # Log AUC
             # create best model for Random Forest
             self.random_forest = self.get_tuned_random_forest_classifier(train_x, train_y)
             self.prediction_random_forest = self.random_forest.predict(
@@ -225,9 +228,17 @@ class ClassificationModelTuner():
                     test_y.unique()) == 1:  # if there is only one label in y, then roc_auc_score returns error. We will use accuracy in that case
                 self.random_forest_score = accuracy_score(test_y, self.prediction_random_forest)
                 self.logger_object.log(self.file_object, 'Accuracy for RF:' + str(self.random_forest_score))
-            else:
+            elif len(test_y.unique()) == 2:
                 self.random_forest_score = roc_auc_score(test_y, self.prediction_random_forest)  # AUC for Random Forest
                 self.logger_object.log(self.file_object, 'AUC for RF:' + str(self.random_forest_score))
+            else:
+                lb = LabelBinarizer()
+                lb.fit(test_y)
+                test_y_rf = lb.transform(test_y)
+                self.prediction_random_forest = lb.transform(self.prediction_random_forest)
+                self.random_forest_score = roc_auc_score(test_y_rf,
+                                                         self.prediction_random_forest)  # AUC for Random Forest
+                self.logger_object.log(self.file_object, 'AUC for RF:' + str(self.random_forest_score))
 
             if (self.random_forest_score < self.xgboost_score):
                 self.file_operation.save_model(self.xgboost, 'XGBoost')
@@ -296,4 +307,4 @@ class ClassificationModelTuner():
                                        e))
             self.logger_object.log(self.file_object,
                                    'Model Selection Failed. Exited the generate_model_report method of the ClassificationModelTuner class')
-            raise Exception()
+            raise Exception()
\ No newline at end of file
