@@ -1,8 +1,7 @@
 import pandas as pd
 # import pymongo
 # import os
-#from appLogger import AppLogger
-from pneuro import appLogger
+from pneuro.appLogger import AppLogger
 
 
 class DataGetter():
@@ -36,8 +35,8 @@ class DataGetter():
         print(os.getcwd())
         self.log_file_name = open(self.log_file,self.file_mode)
         """
-        self.log_file_name = open('dataLoadLogs.txt', 'a+')
-        self.logger = appLogger.AppLogger()
+        self.log_file_name = open('../logs/dataLoadLogs.txt', 'a+')
+        self.logger = AppLogger()
 
     def read_data_from_csv(self, file_name):
         """
@@ -106,7 +105,7 @@ class DataGetter():
 
         self.logger.log(self.log_file_name, 'Entered the read_data_from_json method of the Data_Getter class')
         try:
-            json = pd.read_json(self, file_name)
+            json = pd.read_json(file_name)
             self.logger.log(self.log_file_name, 'Data Load Successful.Exited the read_data_from_json method of the Data_Getter class' )
             return pd.DataFrame(json)
         except Exception as e:
@@ -117,6 +116,32 @@ class DataGetter():
                             'Data Load Unsuccessful.Exited the read_data_from_json method of the Data_Getter class')
             raise Exception()
 
+    def read_data_from_text(self, file_name, delim):
+        """
+                       Method Name: read_data_from_text
+                       Description: This method reads the data from a text file.
+                       Output: A pandas DataFrame.
+                       On Failure: Raise Exception
+
+                       Written By: iNeuron Intelligence
+                       Version: 1.0
+                       Revisions: None
+
+                       """
+
+
+        self.logger.log(self.log_file_name, 'Entered the read_data_from_text method of the Data_Getter class')
+        try:
+            text = pd.read_csv(file_name, sep = delim, header = "infer")
+            self.logger.log(self.log_file_name, 'Data Load Successful.Exited the read_data_from_text method of the Data_Getter class' )
+            return pd.DataFrame(text)
+        except Exception as e:
+            self.logger.log(self.log_file_name,
+                            'Exception occured in read_data_from_json method of the Data_Getter class. Exception message: ' + str(
+                                e))
+            self.logger.log(self.log_file_name,
+                            'Data Load Unsuccessful.Exited the read_data_from_json method of the Data_Getter class')
+            raise Exception()
 
     def read_data_from_html(self, file_name):
         """
@@ -133,7 +158,7 @@ class DataGetter():
 
         self.logger.log(self.log_file_name, 'Entered the read_data_from_html method of the Data_Getter class')
         try :
-            html = pd.read_html(self, file_name)
+            html = pd.read_html(file_name)
             data = html[0]
             self.logger.log(self.log_file_name, 'Data Load Successful.Exited the read_data_from_html method of the Data_Getter class')
             return pd.DataFrame(data)
@@ -164,7 +189,7 @@ class DataGetter():
         return pd.DataFrame(mydb)
     """
 
-    def get_data(self, file_type, file):
+    def get_data(self, file_type, file, delim):
         """
                         Method Name: get_data
                         Description: This method reads the data based on the file
@@ -180,22 +205,34 @@ class DataGetter():
         self.logger.log(self.log_file_name, 'Entered the get_data method of '
                                             'the Data_Getter class')
         try:
-            if file_type == 'CSV':
+            if file_type == 'csv':
                 data = self.read_data_from_csv(file)
                 self.logger.log(self.log_file_name,
                                     'Data Load Successful.Exited the get_data method of the Data_Getter class')
-            if file_type == 'xlsx':
+            elif file_type == 'xlsx':
                 data = self.read_data_from_excel(file)
                 self.logger.log(self.log_file_name,
                                     'Data Load Successful.Exited the get_data method of the Data_Getter class')
-            if file_type == 'html':
+            elif file_type == 'html':
                 data = self.read_data_from_html(file)
                 self.logger.log(self.log_file_name,
                                     'Data Load Successful.Exited the get_data method of the Data_Getter class')
-            if file_type == 'json':
+            elif file_type == 'json':
                 data = self.read_data_from_json(file)
                 self.logger.log(self.log_file_name,
                                     'Data Load Successful.Exited the get_data method of the Data_Getter class')
+
+                self.logger.log(self.log_file_name,
+                            'Data Load Successful.Exited the get_data method of the Data_Getter class')
+
+            elif file_type == 'txt':
+                data = self.read_data_from_text(file,delim)
+                self.logger.log(self.log_file_name,
+                                'Data Load Successful.Exited the get_data method of the Data_Getter class')
+
+                self.logger.log(self.log_file_name,
+                                'Data Load Successful.Exited the get_data method of the Data_Getter class')
+            data.columns=data.columns.str.replace(r'\s+', '') # remove spaces from the column names
             return data
         except Exception as e:
             self.logger.log(self.log_file_name,
