@@ -2,8 +2,7 @@ import pickle
 import os
 import shutil
 
-#from appLogger import AppLogger
-from pneuro import appLogger
+from pneuro.appLogger import AppLogger
 
 
 class FileOperation:
@@ -18,8 +17,8 @@ class FileOperation:
                 """
 
     def __init__(self):
-        self.file_object = open('fileOperationLogs.txt', 'a+')
-        self.logger_object = appLogger.AppLogger()
+        self.file_object = open('pneuro/logs/fileOperationLogs.txt', 'a+')
+        self.logger_object = AppLogger()
         self.model_directory = 'models/'
 
     def save_model(self, model, filename):
