@@ -5,10 +5,11 @@ from imblearn.over_sampling import RandomOverSampler, SMOTE
 from imblearn.under_sampling import RandomUnderSampler
 from sklearn.feature_selection import VarianceThreshold
 from sklearn.preprocessing import StandardScaler
+from sklearn.preprocessing import LabelEncoder
 from sklearn.preprocessing import MinMaxScaler
 
-#from appLogger import AppLogger
-from pneuro import appLogger
+from pneuro.appLogger import AppLogger
+
 
 class Preprocessor():
     """
@@ -22,8 +23,8 @@ class Preprocessor():
     """
 
     def __init__(self):
-        self.file_object = open('dataPreprocessingLogs.txt', 'a+')
-        self.logger_object = appLogger.AppLogger()
+        self.file_object = open('pneuro/logs/dataPreprocessingLogs.txt', 'a+')
+        self.logger_object = AppLogger()
 
     def get_data_profile(self, data):
         """
@@ -114,10 +115,13 @@ class Preprocessor():
         self.data = data
         self.columns = columns
         try:
-            self.useful_data = self.data.drop(labels=self.columns, axis=1)  # drop the labels specified in the columns
-            self.logger_object.log(self.file_object,
+            if self.columns is not None:
+                self.useful_data = self.data.drop(labels=self.columns, axis=1, errors='ignore' )  # drop the labels specified in the columns
+                self.logger_object.log(self.file_object,
                                    'Column removal Successful.Exited the remove_columns method of the Preprocessor class')
-            return self.useful_data
+                return self.useful_data
+            else:
+                return self.data
         except Exception as e:
             self.logger_object.log(self.file_object,
                                    'Exception occured in remove_columns method of the Preprocessor class. Exception message:  ' + str(
@@ -385,7 +389,7 @@ class Preprocessor():
                                        e))  # Logging the exception message
             raise Exception()  # raising exception and exiting
 
-    def standardize_data(self, dataframe):
+    def standardize_data(self, dataframe, process='train'):
 
         """
         Method Name: standardize_data
@@ -400,12 +404,19 @@ class Preprocessor():
         Revisions: None
 
         """
+        global stdscalar #if this function gives error, check this
         try:
-            data = dataframe
-            stdscalar = StandardScaler()
-            scaled_data = stdscalar.fit_transform(data)
-            scaled_data = pd.Dataframe(data=scaled_data, columns=data.columns)
-            return scaled_data
+            if process=='train':
+                data = dataframe
+                stdscalar = StandardScaler()
+                scaled_data = stdscalar.fit_transform(data)
+                scaled_data = pd.DataFrame(data=scaled_data, columns=data.columns)
+                return scaled_data
+            else:
+                data = dataframe
+                scaled_data = stdscalar.transform(data)
+                scaled_data = pd.DataFrame(data=scaled_data, columns=data.columns)
+                return scaled_data
         except Exception as e:
             self.logger_object.log(self.file_object,
                                    'Exception occured while stadardizing data. Exception message:  ' + str(e))
@@ -430,7 +441,7 @@ class Preprocessor():
             data = dataframe
             normalizer = MinMaxScaler()
             normalized_data = normalizer.fit_transform(data)
-            normalized_data = pd.Dataframe(data=normalized_data, columns=data.columns)
+            normalized_data = pd.DataFrame(data=normalized_data, columns=data.columns)
             return normalized_data
         except Exception as e:
             self.logger_object.log(self.file_object,
@@ -502,15 +513,51 @@ class Preprocessor():
 
             raise Exception()
 
-    def preprocess(self, dataset, target_column,unwanted_cols):
-        dataset = self.remove_columns(dataset, columns=['Unnamed: 0'])
-        dataset = self.impute_missing_values(data=dataset, mv_flag=True, target=target_column)
-        # dataset = self.remove_columns(dataset, unwanted_cols)
-        dataset = self.remove_imbalance(dataset, target_column, threshold=10.0, oversample=True, smote=False)
-        dataset, self.y = self.separate_label_feature(dataset, target_column)
-        self.x = self.remove_columns_with_minimal_variance(data=dataset, threshold=0.1)
+    def label_encoding(self, dataframe):
 
+        """
+        Method Name: corelation_heatmap
+        Description: This method will be used to plot the heatmap to show the corelation among the variables
 
+        Input Description: data: the input dataframe with target column.
 
+        Output: plot of heatmap that shows the corelation among the variable.
+        On Failure: Raise Exception
+
+        Written By: shakti kumar
+        Version: 1.0
+        Revisions: None
+
+        """
+        try:
+            data = dataframe
+            le = LabelEncoder()
+            for i in data.columns:
+                if data[i].dtype == 'O':
+                    data[i] = le.fit_transform(data[i])
+        except Exception as e:
+            self.logger_object.log(self.file_object,
+                                   'Exception occured in plotting correlation heatmap. Exception message: ' + str(
+                                       e))  # Logging the exception message
+            self.logger_object.log(self.file_object,
+                                   'Plotting of heatmap fails.Exited the correlation_heatmap method of the DataVisualization class')  # Logging unsuccessful load of data
+            raise Exception()  # raising exception and exiting
+        return data
+
+    def preprocess(self, dataset, target_column, unwanted_cols, process='train'):
+        dataset = self.remove_columns(dataset, unwanted_cols)
+        if len(dataset)>1:
+            dataset = self.impute_missing_values(data=dataset, mv_flag=True, target=target_column)
+            #self.x = self.remove_columns_with_minimal_variance(data=dataset, threshold=0.1)
+        self.x = self.label_encoding(dataset) #this needs to be corrected at a later stage(encoding needs to be retained for prediction, specially the categorical target)
+        if process=='train':
+            dataset = self.remove_imbalance(dataset, target_column, threshold=10.0, oversample=True, smote=False)
+            self.x, self.y = self.separate_label_feature(dataset, target_column)
+            self.x = self.standardize_data(self.x)
+            #self.x = self.pca(dataset, 0.90)
+            return self.x, self.y
+        else:
+
+            self.x = self.standardize_data(self.x.drop(columns=target_column), process='predict')
+            return self.x
 
-        return self.x, self.y
