@@ -10,8 +10,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 import seaborn as sns
 
-#from appLogger import AppLogger
-from pneuro import appLogger
+from pneuro.appLogger import AppLogger
 
 
 class DataVisualization:
@@ -25,8 +24,8 @@ class DataVisualization:
     """
 
     def __init__(self):
-        self.file_object = open('dataVisualizationLogs.txt', 'a+')
-        self.logger_object = appLogger.AppLogger()
+        self.file_object = open('pneuro/logs/dataVisualizationLogs.txt', 'a+')
+        self.logger_object = AppLogger()
 
     def balance_imbalance_check(self, dataframe, target):
 
@@ -49,13 +48,22 @@ class DataVisualization:
         try:
             # x = sns.countplot(target,data=dataframe).set_title("Balance Imbalance Count")
             # sns.barplot(x = 'is_promoted', y = 'is_promoted' ,data=df, hue  = 'is_promoted', estimator = lambda x: len(x)/len(df) *100).set_title("Balance Imbalance Count")
-            sns.barplot(x='is_promoted', y='is_promoted', data=dataframe,
-                        estimator=lambda x: len(x) / len(dataframe) * 100)
-            plt.xlabel('ispromoted')
-            plt.ylabel('percentage')
-            plt.title('Balance Imbalance Count')
-            plt.savefig("static/graphs/imbalance.png")
+            # sns.barplot(x='is_promoted', y='is_promoted', data=dataframe,
+            #             estimator=lambda x: len(x) / len(dataframe) * 100)
+            # plt.xlabel('ispromoted')
+            # plt.ylabel('percentage')
+            # plt.title('Balance Imbalance Count')
+            # plt.savefig("static/graphs/imbalance.png")
+            print(list(target.value_counts().index))
+            print((target.value_counts().iloc[:,0]))
+            plotdata=[go.Bar(
+                data=dataframe,
+                x=list(target.value_counts().index),
+                y= (target.value_counts())
+            )]
+            graphJSON = json.dumps(plotdata, cls=plotly.utils.PlotlyJSONEncoder)
 
+            return graphJSON
         except Exception as e:
             self.logger_object.log(self.file_object,
                                    'Exception occured in checking balance and imbalance of the target(Graphically). Exception message: ' + str(
@@ -79,6 +87,7 @@ class DataVisualization:
         Revisions: None
 
         """
+        self.logger_object.log(self.file_object,'Entered corelation heat map method')
         try:
 
             data = dataframe.select_dtypes(include=[np.number])
@@ -94,13 +103,12 @@ class DataVisualization:
                 y=list(data.columns)
                 ,dx=1,dy=1
                 )]
+            
             graphJSON = json.dumps(plotdata, cls=plotly.utils.PlotlyJSONEncoder)
+            self.logger_object.log(self.file_object, 'Exited corelation heat map method')
 
             return graphJSON
 
-
-
-
         except Exception as e:
             self.logger_object.log(self.file_object,
                                    'Exception occured in plotting correlation heatmap. Exception message: ' + str(
